;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "orglink" "20251101.2047"
  "Use Org Mode links in other modes."
  '((emacs  "26.1")
    (compat "30.1")
    (org    "9.7")
    (seq    "2.24"))
  :url "https://github.com/tarsius/orglink"
  :commit "1f76298c90ee1c7f4b1c77ab2389f304ea75fc8b"
  :revdesc "1f76298c90ee"
  :keywords '("hypermedia")
  :authors '(("Jonas Bernoulli" . "emacs.orglink@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.orglink@jonas.bernoulli.dev")))
